#!/bin/sh

srcdir=`dirname $0`
test -z "$srcdir" && srcdir=.

libtoolize --copy --force \
  && aclocal \
  && autoheader
automake --add-missing --foreign --copy 

automake_version=`automake --version  |grep automake |sed 's/^[^0-9]*\([0-9.][0-9.]*\).*/\1/'`
case "$automake_version" in
  1.8*|1.9*) cp -f mkinstalldirs.dist mkinstalldirs ;;
esac

autoconf
